==> GANN-Beta-1.5.tar.gz: GANN/src/gremdata.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Remove Data From GKDB
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Geeks Remove Data (Function)
void GRemData(int RegNum)

{

    //Variables
    int i,j,k,n;
    int Tmp1,Tmp2;
    int GHT[MAX_REG];
    float GKDB[MAX_REG];
    float TMP[MAX_REG];
    FILE *FileToUpdate;
    
    //Reset
    i=0;
    j=0;
    k=0;
    n=0;
    
    //Initialize GHT
    FileToUpdate=fopen("GHT","r");
    
    //Error Check
    if (FileToUpdate==NULL)
    
    {
    
        printf("Error: GKDB Has Not Been Found!\n");
        
        exit(1);
    
    }
    
    //Read The GHT
    while ((n=feof(FileToUpdate))==FALSE)
    
    {
    
        fscanf(FileToUpdate,"%i\n",&GHT[i]);
        
        i++;
    
    }
    
    //Keep GHT Bound In Tmp1
    Tmp1=i;
    
    //Close GHT
    fclose(FileToUpdate);
    
    //Read Registry Offset (Head)
    for (i=0;i<RegNum;i++)
        j=GHT[i];
    
    //Keep Registry Position In Tmp2
    Tmp2=i;
    
    //Read Next Offset (End)
    for (i=RegNum;i<RegNum+1;i++)
        k=GHT[i];
    
    //Error Checks
    if (k==0 AND RegNum>1)
    
    {
    
        printf("Error: This Registration Does Not Exist!\n");
        
        exit(1);
    
    }
    
    if (k==0)
        k=j;
    
    //Update GHT
    for (i=0;i<Tmp1;i++)
        GHT[Tmp2+i]=GHT[Tmp2+i+1];
    
    //Initialize GHT
    FileToUpdate=fopen("GHT","w");
    
    //Check If Only One Registration Exists
    if (Tmp1==1)
    
    {
    
        system("rm GHT GKDB");
        
        printf("GKDB Deleted - No Other Entries Exist!\n");
        
        exit(0);
    
    }
    
    else
    
    {
    
        for (i=0;i<Tmp1;i++)
            fprintf(FileToUpdate,"%i\n",GHT[i]);
    
    }
    
    //Close GHT
    fclose(FileToUpdate);
    
    //Reset
    i=0;
    n=0;
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","r");
    
    //Read GKDB
    while ((n=feof(FileToUpdate))==FALSE)
    
    {
    
        fscanf(FileToUpdate,"%f\n",&GKDB[i]);
        
        i++;
    
    }
    
    //Keep GKDB Bound In Tmp1
    Tmp1=i;
    
    //Close GKDB
    fclose(FileToUpdate);
    
    //Reset
    i=0;
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","r");
    
    //Set Pointer At Specified Registry
    fseek(FileToUpdate,j,SEEK_SET);
    
    //Read GKDB
    while (j!=k)
    
    {
    
        fscanf(FileToUpdate,"%f\n",&TMP[i]);
        
        j=ftell(FileToUpdate);
        
        i++;
    
    }
    
    //Keep TMP Bound In Tmp2
    Tmp2=i;
    
    //Close GKDB
    fclose(FileToUpdate);
    
    //Update GKDB
    for (i=0;i<Tmp1;i++)
    
    {
    
        for (j=0;j<Tmp2;j++)
        
        {
        
            if (GKDB[i]=TMP[j] AND i>=Tmp2)
                GKDB[i]=GKDB[i+1];
        
        }
    
    }
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","w");
    
    //Save New GKDB
    
    
    //Close GKDB
    fclose(FileToUpdate);

}

/* ------------------------------------------------------------------------ */

==> GANN-Beta-1.6.tar.gz: GANN/src/gremdata.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Remove Data From GKDB
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Geeks Remove Data (Function)
void GRemData(int GRegSerNum)

{
/*
    //Variables
    int i,j,k,n;
    int Tmp1,Tmp2;
    int GHT[MAX_REG];
    float GKDB[MAX_REG];
    float TMP[MAX_REG];
    FILE *FileToUpdate;
    
    //Reset
    i=0;
    j=0;
    k=0;
    n=0;
    
    //Initialize GHT
    FileToUpdate=fopen("GHT","r");
    
    //Error Check
    if (FileToUpdate==NULL)
    
    {
    
        printf("Error: GKDB Has Not Been Found!\n");
        
        exit(1);
    
    }
    
    //Read The GHT
    while ((n=feof(FileToUpdate))==FALSE)
    
    {
    
        fscanf(FileToUpdate,"%i\n",&GHT[i]);
        
        i++;
    
    }
    
    //Keep GHT Bound In Tmp1
    Tmp1=i;
    
    //Close GHT
    fclose(FileToUpdate);
    
    //Read Registry Offset (Head)
    for (i=0;i<RegNum;i++)
        j=GHT[i];
    
    //Keep Registry Position In Tmp2
    Tmp2=i;
    
    //Read Next Offset (End)
    for (i=RegNum;i<RegNum+1;i++)
        k=GHT[i];
    
    //Error Checks
    if (k==0 AND RegNum>1)
    
    {
    
        printf("Error: This Registration Does Not Exist!\n");
        
        exit(1);
    
    }
    
    if (k==0)
        k=j;
    
    //Update GHT
    for (i=0;i<Tmp1;i++)
        GHT[Tmp2+i]=GHT[Tmp2+i+1];
    
    //Initialize GHT
    FileToUpdate=fopen("GHT","w");
    
    //Check If Only One Registration Exists
    if (Tmp1==1)
    
    {
    
        system("rm GHT GKDB");
        
        printf("GKDB Deleted - No Other Entries Exist!\n");
        
        exit(0);
    
    }
    
    else
    
    {
    
        for (i=0;i<Tmp1;i++)
            fprintf(FileToUpdate,"%i\n",GHT[i]);
    
    }
    
    //Close GHT
    fclose(FileToUpdate);
    
    //Reset
    i=0;
    n=0;
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","r");
    
    //Read GKDB
    while ((n=feof(FileToUpdate))==FALSE)
    
    {
    
        fscanf(FileToUpdate,"%f\n",&GKDB[i]);
        
        i++;
    
    }
    
    //Keep GKDB Bound In Tmp1
    Tmp1=i;
    
    //Close GKDB
    fclose(FileToUpdate);
    
    //Reset
    i=0;
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","r");
    
    //Set Pointer At Specified Registry
    fseek(FileToUpdate,j,SEEK_SET);
    
    //Read GKDB
    while (j!=k)
    
    {
    
        fscanf(FileToUpdate,"%f\n",&TMP[i]);
        
        j=ftell(FileToUpdate);
        
        i++;
    
    }
    
    //Keep TMP Bound In Tmp2
    Tmp2=i;
    
    //Close GKDB
    fclose(FileToUpdate);
    
    //Update GKDB
    for (i=0;i<Tmp1;i++)
    
    {
    
        for (j=0;j<Tmp2;j++)
        
        {
        
            if (GKDB[i]=TMP[j] AND i>=Tmp2)
                GKDB[i]=GKDB[i+1];
        
        }
    
    }
    
    //Initialize GKDB
    FileToUpdate=fopen("GKDB","w");
    
    //Save New GKDB
    
    
    //Close GKDB
    fclose(FileToUpdate);
*/
}

/* ------------------------------------------------------------------------ */
